/*
 * Copyright 2020 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.devsite.components.impl

import com.google.devsite.components.symbols.ClassSignature
import com.google.devsite.components.symbols.render
import com.google.devsite.renderer.Language
import kotlinx.html.FlowContent
import kotlinx.html.pre

internal class DefaultClassSignature(
    override val data: ClassSignature.Params
) : ClassSignature {

    override fun render(into: FlowContent) {

        into.run {
            pre {
                +(data.modifiers + data.type + data.name).joinToString(separator = " ")

                data.typeParameters.render(this)

                when (data.displayLanguage) {
                    Language.JAVA -> {
                        for ((i, value) in data.extends.withIndex()) {
                            if (i == 0) {
                                +" extends "
                            } else {
                                +", "
                            }
                            value.render(this)
                        }
                        for ((i, value) in data.implements.withIndex()) {
                            if (i == 0) {
                                +" implements "
                            } else {
                                +", "
                            }
                            value.render(this)
                        }
                    }
                    Language.KOTLIN -> {
                        for ((i, value) in (data.extends + data.implements).withIndex()) {
                            if (i == 0) {
                                +" : "
                            } else {
                                +", "
                            }
                            value.render(this)
                        }
                    }
                }
            }
        }
    }
}
