/*
 * Copyright 2020 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.devsite.components.pages

import com.google.devsite.components.ContextFreeComponent
import com.google.devsite.components.symbols.ClassSignature
import com.google.devsite.components.table.ClassHierarchy
import com.google.devsite.components.table.InheritedSymbols
import com.google.devsite.components.table.RelatedSymbols
import com.google.devsite.components.table.SummaryList

/** Represents class-like pages (class, interface, exception, etc). */
internal interface Classlike : ContextFreeComponent {
    val data: Params

    class Params(
        val signature: ClassSignature,
        val hierarchy: ClassHierarchy,
        val relatedSymbols: RelatedSymbols,
        val description: List<ContextFreeComponent>,
        val symbolTypes: List<Pair<SummaryList, SymbolType>>,
        val inheritedTypes: List<InheritedSymbols>
    )

    data class SymbolType(val title: String, val symbols: List<ContextFreeComponent>)
}
